@@ -698,7 +698,7 @@ function callback_attach(cb) {
         ExecAfterUpload();    
     }
     else {
-        //triggerEvent("OX_New_Error", 4, cb.toString());
+        callback_error(cb);
     }
 }
 
