@@ -147,61 +147,68 @@ cAnimMiniCalendar.prototype = {
 			else
 				jQuery(Self.nodes[0]).parent()[0].scrollLeft = nStart - Math.log(Math.pow(nStep,0.66))*66;
 		}
-		animate((configGetKey("gui.effects.fading") ? 750 : 0), 245, do_scroll,cb_fn);
+		animate(0, 245, do_scroll,cb_fn);
 	},
 	
-	next: function(num) {
-		var Self = this;		
+	next: function (num) {
+		var Self = this;
 		if (!this.checkloaded() || this.animationInProgress) return;
         var NextDate = new Date(Date.UTC(this.MiniRefer.currentYear,
                                          this.MiniRefer.currentMonth + num));
-		Self.MiniRefer.set_header(NextDate);		
-		this.MiniRefer.appointmentList = new Array();	
+		Self.MiniRefer.set_header(NextDate);
+		this.MiniRefer.appointmentList = new Array();
 		Self.MiniRefer.currentMonth = NextDate.getUTCMonth();
-		Self.MiniRefer.currentYear = NextDate.getUTCFullYear();																
-		Self.MiniRefer.oCalendar = new cCalendar(NextDate.getUTCMonth(),NextDate.getUTCFullYear());		
+		Self.MiniRefer.currentYear = NextDate.getUTCFullYear();
+		Self.MiniRefer.oCalendar = new cCalendar(NextDate.getUTCMonth(),NextDate.getUTCFullYear());
 		var oNextTable = this.MiniRefer.getTable(Self.MiniRefer.oCalendar);
 		var switchsubContainer = newnode('div',{ left:"239px", position:"absolute" });
 		switchsubContainer.appendChild(oNextTable);
 		this.nodes[0].appendChild(switchsubContainer);
 		this.animationInProgress = true;
 		jQuery(this.nodes[0]).parent()[0].scrollLeft = 0;
-		this.MiniRefer.subcontainer.style.left = "0px";		
-		this.scroll(1, function(){
-			Self.nodes[0].removeChild(Self.MiniRefer.subcontainer);
+		this.MiniRefer.subcontainer.style.left = "0px";	
+		this.scroll(1, function() {
+		    jQuery(Self.MiniRefer.subcontainer).remove();
 			Self.MiniRefer.subcontainer = switchsubContainer;
+			jQuery(Self.MiniRefer.subcontainer).css({ left: 0 });
+			jQuery(Self.nodes[0]).parent().css({ width: "" }).first().css({ left: 0 });
 			Self.animationInProgress = false;
-			if(Self.MiniRefer.displayAppointments)
-				Self.MiniRefer.update();						
+			if (Self.MiniRefer.displayAppointments) {
+				Self.MiniRefer.update();
+			}
 		});
 	},
 	
 	back: function(num) {
-		var Self = this;		
+		var Self = this;
 		if (!this.checkloaded() || this.animationInProgress) return;
         var NextDate = new Date(Date.UTC(this.MiniRefer.currentYear,
                                          this.MiniRefer.currentMonth - num));
 		Self.MiniRefer.set_header(NextDate);	
-		this.MiniRefer.appointmentList = new Array();	
-		Self.MiniRefer.currentMonth = NextDate.getUTCMonth();								
-		Self.MiniRefer.currentYear = NextDate.getUTCFullYear();																
-		Self.MiniRefer.oCalendar = new cCalendar(NextDate.getUTCMonth(),NextDate.getUTCFullYear());		
+		this.MiniRefer.appointmentList = new Array();
+		Self.MiniRefer.currentMonth = NextDate.getUTCMonth();
+		Self.MiniRefer.currentYear = NextDate.getUTCFullYear();
+		Self.MiniRefer.oCalendar = new cCalendar(NextDate.getUTCMonth(),NextDate.getUTCFullYear());
 		var oNextTable = this.MiniRefer.getTable(Self.MiniRefer.oCalendar);
 		var switchsubContainer = newnode('div',{ left:"0px", position:"absolute" });
 		switchsubContainer.appendChild(oNextTable);
 		this.nodes[0].insertBefore(switchsubContainer, this.MiniRefer.subcontainer);
 		this.animationInProgress = true;
+		jQuery(this.nodes[0]).parent()[0].scrollLeft = "245px";
 		this.MiniRefer.subcontainer.style.left = "239px";
-		jQuery(this.nodes[0]).parent()[0].scrollLeft = 245;
-		this.scroll(-1,function (){
-			Self.nodes[0].removeChild(Self.MiniRefer.subcontainer);
-				Self.MiniRefer.subcontainer = switchsubContainer;
-				Self.animationInProgress = false;
-				if(Self.MiniRefer.displayAppointments)
-					Self.MiniRefer.update();
-			});
+		this.scroll(-1, function() {
+            jQuery(Self.MiniRefer.subcontainer).remove();
+            Self.MiniRefer.subcontainer = switchsubContainer;
+            jQuery(Self.MiniRefer.subcontainer).css({ left: 0 });
+            jQuery(Self.nodes[0]).parent().css({ width: "" }).first().css({ left: 0 });
+            Self.animationInProgress = false;
+            if (Self.MiniRefer.displayAppointments) {
+                Self.MiniRefer.update();
+            }
+        });
 	},
-	go_to: function(oDate){
+	
+	go_to: function (oDate){
 		this.MiniRefer.go_to(oDate);
 	},
 	
@@ -833,6 +840,7 @@ cMiniCalendar.prototype = {
 			this.go_to(new Date(Date.UTC(this.selectedYear,
 			                             this.selectedMonth)));
 		}
+		calendar_activedate = new Date(this.selectedTime);
 	},
 	
 	/**
