@@ -426,12 +426,12 @@ WeekCalendarTool.prototype = {
 	},
 	sortAppointments: function() {
 		this.weekAppointments.sort(
-			function(a, b){
-				return (a[9] || a[4] < b[4] ? -1 : 1); 
+			function (a, b) {
+			    return a[9] ? -1 : b[9] ? 1 : a[4] < b[4] ? -1 : 1;
 			}
 		);
-		for(var i=0; i<this.weekAppointments.length;i++) {
-			this.generateCalendarObjects(this.weekAppointments[i]["indxxx"],this.weekAppointments[i]);
+		for (var i=0; i<this.weekAppointments.length; i++) {
+			this.generateCalendarObjects(this.weekAppointments[i]["indxxx"], this.weekAppointments[i]);
 		}
 	},
 	getAppointmentDiv:function (object) {
