@@ -231,7 +231,7 @@ window.SubscribeFolder = (function () {
                 });
             }
             
-            if (folder.own_rights & 0x3f80) {
+            if ((folder.own_rights & 0x3f80) && !folder.standard_folder) {
                 iNode = newnode("input", 0, {
                     type: "checkbox",
                     id: "sub_folder_" + folder.id, 
