@@ -88,6 +88,13 @@ function() {
             }
     );
     
+    function enableDnD(grid, folder) {
+        var api = ox.api.folder, data = api.get({ folder: folder }),
+            canMove = api.can("delete", data) && !api.is("shared", data);
+        console.log('enableDnD', canMove, api.can("delete", data), api.is("shared", data), data);
+        grid.dndModule = canMove ? "tasks" : "";
+    }
+    
     registerView("tasks/list",
         function() {
             showNode("taskslist");
@@ -99,6 +106,7 @@ function() {
             if (tasksSearchObject !== null) {
                 taskSearch(tasksSearchObject.module, tasksSearchObject.pattern);
             } else {
+                enableDnD(gridlist, activefolder);
                 gridlist.enable(criteria);
             }
             tasks_setFocus(gridlist);
@@ -128,6 +136,7 @@ function() {
              if (changeFolder != undefined) {
                  var criteria = { "folder_id" : activefolder };
                  gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
+                 enableDnD(gridlist, activefolder);
                  gridlist.enable(criteria, false);
                  tasks_setFocus(gridlist);
                  triggerEvent("Confirmation_Changed", 0);
@@ -154,6 +163,7 @@ function() {
                 if (tasksSearchObject !== null) {
                     taskSearch(tasksSearchObject.module, tasksSearchObject.pattern);
                 } else {
+                    enableDnD(gridsplit, activefolder);
                     gridsplit.enable(criteria);
                 }
                 // reselect id if it's a direct link for example
@@ -203,6 +213,7 @@ function() {
                 if (changeFolder != undefined) {
                     var criteria= { "folder_id" : activefolder };
                     gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
+                    enableDnD(gridsplit, activefolder);
                     gridsplit.enable(criteria, false);
                     tasks_setFocus(gridsplit);
                     // update confirm button
@@ -313,9 +324,11 @@ function() {
         var search= { "note" : "*"+pattern+"*" , "title" : "*"+pattern+"*", "categories" : "*"+pattern+"*" };
         if (currentpath2[1] == "split") {
           gridsplit.disablehover=!configGetKey("gui.effects.hover.tasks");
+          enableDnD(gridsplit, activefolder);
           gridsplit.enable(criteria,search,false);
         } else if(currentpath2[1] == "list") {
           gridlist.disablehover=!configGetKey("gui.effects.hover.tasks");
+          enableDnD(gridlist, activefolder);
           gridlist.enable(criteria,search,false);
         }
         tasksFolderPath.drawSearch(module, pattern);
@@ -330,6 +343,7 @@ function() {
         }    
         split.searchActive=false;
         split.disablehover=!configGetKey("gui.effects.hover.tasks");
+        enableDnD(split, activefolder);
         split.enable(criteria);
         tasksFolderPath.drawDOMNode(view, activefolder);
     }
