@@ -1350,7 +1350,8 @@ function pageModified() {
             if(!(child in a)) return false;
         return true;
     }
-    return this.listModified || !equals(this.get(), this.original);
+    return this.listModified ||
+        ("original" in this) && !equals(this.get(), this.original);
 }
 
 function initVacationPage() {
